@@ -12,16 +12,16 @@
 #    and/or other materials provided with the distribution.
 
 
-version = '3.0.2'
+version = '3.1.0'
 
 from .celestial import CelestialCoord, angle_units, arcsec, arcmin, degrees, hours, radians
-from .config import read_config
+from .config import read_config, set_omp_threads
 from .corr2 import corr2, print_corr2_params
 from .catalog import Catalog, read_catalogs, calculateVarG, calculateVarK
-from .binnedcorr2 import BinnedCorr2, SetOMPThreads
-from .g2correlation import G2Correlation
-from .n2correlation import N2Correlation
-from .k2correlation import K2Correlation
+from .binnedcorr2 import BinnedCorr2
+from .ggcorrelation import GGCorrelation
+from .nncorrelation import NNCorrelation
+from .kkcorrelation import KKCorrelation
 from .ngcorrelation import NGCorrelation
 from .nkcorrelation import NKCorrelation
 from .kgcorrelation import KGCorrelation
