@@ -10,28 +10,13 @@
 # 2. Redistributions in binary form must reproduce the above copyright notice,
 #    this list of conditions, and the disclaimer given in the documentation
 #    and/or other materials provided with the distribution.
+"""
+.. module:: catalog
+"""
 
 import treecorr
 import numpy
 
-def isKColRequired(config, num):
-    """A quick helper function that checks whether we need to bother reading the k column.
-    """
-    return ( 'k2_file_name' in config
-             or (num==0 and 'kg_file_name' in config)
-             or (num==1 and 'nk_file_name' in config) )
-
-def isGColRequired(config, num):
-    """A quick helper function that checks whether we need to bother reading the g1,g2 columns.
-    """
-    return ( 'g2_file_name' in config
-             or 'm2_file_name' in config
-             or 'norm_file_name' in config
-             or (num==1 and 'ng_file_name' in config)
-             or (num==1 and 'nm_file_name' in config)
-             or (num==1 and 'kg_file_name' in config) )
-
-
 class Catalog(object):
     """A classs storing the catalog information for a particular set of objects
     to be correlated in some way.
@@ -56,13 +41,20 @@ class Catalog(object):
     first elements of these vectors (i.e. no g1 or g2 columns), and for the second file, you
     would use num=1 to use columsn 3 and 4.
 
+    You may also specify any any configuration parameters as kwargs to the Catalog constructor
+    if you prefer to either add parameters that are not present in the config dict or to supersede
+    values in the config dict.  You can even provide all parameters as kwargs and omit the config
+    dict entirely:
+
+        >>> cat1 = treecorr.Catalog(file_name, config, flip_g1=True)
+        >>> cat2 = treecorr.Catalog(file_name, ra_col=1, dec_col=2, ra_units='deg', dec_units='deg')
+
     An alternate way to build a Catalog is to provide the data vectors by hand.  This may
     be more convenient when using this as part of a longer script where you are building the
     data vectors in python and then want to compute the correlation function.  The syntax for this
     is:
 
-        >>> cat = treecorr.Catalog(g1=g1, g2=g2, ra=ra, dec=dec,
-                                   ra_units=ra_units, dec_units=dec_units)
+        >>> cat = treecorr.Catalog(g1=g1, g2=g2, ra=ra, dec=dec, ra_units='hour', dec_units='deg')
 
     Each of these data vectors should be a numpy array.  For x,y, the units fields are optional,
     in which case the units are assumed to be arcsec.  But for ra,dec they are required.
@@ -73,24 +65,49 @@ class Catalog(object):
 
     A Catalog object will have available the following attributes:
 
-        x           The x positions, if defined, as a numpy array. (None otherwise)
-        y           The y positions, if defined, as a numpy array. (None otherwise)
-        ra          The right ascension, if defined, as a numpy array. (None otherwise)
-        dec         The declination, if defined, as a numpy array. (None otherwise)
-        r           The distance, if defined, as a numpy array. (None otherwise)
-        w           The weights, as a numpy array. (All 1's if no weight column provided.)
-        g1          The g1 component of the shear, if defined, as a numpy array. (None otherwise)
-        g2          The g2 component of the shear, if defined, as a numpy array. (None otherwise)
-        k           The convergence, kappa, if defined, as a numpy array. (None otherwise)
+        :x:      The x positions, if defined, as a numpy array. (None otherwise)
+        :y:      The y positions, if defined, as a numpy array. (None otherwise)
+        :ra:     The right ascension, if defined, as a numpy array. (None otherwise)
+        :dec:    The declination, if defined, as a numpy array. (None otherwise)
+        :r:      The distance, if defined, as a numpy array. (None otherwise)
+        :w:      The weights, as a numpy array. (All 1's if no weight column provided.)
+        :g1:     The g1 component of the shear, if defined, as a numpy array. (None otherwise)
+        :g2:     The g2 component of the shear, if defined, as a numpy array. (None otherwise)
+        :k:      The convergence, kappa, if defined, as a numpy array. (None otherwise)
 
-        nobj        The number of objects with non-zero weight
-        sumw        The sum of the weights
-        varg        The shear variance (aka shape noise)
-        vark        The kappa variance
-        name        When constructed from a file, this will be the file_name.  It is only used as
-                    a reference name in logging output  after construction, so if you construct it 
-                    from data vectors directly, it will be ''.  You may assign to it if you want to
-                    give this catalog a specific name.
+        :nobj:   The number of objects with non-zero weight
+        :sumw:   The sum of the weights
+        :varg:   The shear variance (aka shape noise) (0 if g1,g2 are not defined)
+        :vark:   The kappa variance (0 if k is not defined)
+
+        :name:   When constructed from a file, this will be the file_name.  It is only used as
+                 a reference name in logging output  after construction, so if you construct it 
+                 from data vectors directly, it will be ''.  You may assign to it if you want to
+                 give this catalog a specific name.
+
+    :param file_name:   The name of the catalog file to be read in. (default: None, in which case
+                        the columns need to be entered directly with `x`, `y`, etc.)
+    :param config:      The configuration dict which defines attributes about how to read the file.
+                        Any kwargs that are not those listed here will be added to the config, 
+                        so you can even omit the config dict and just enter all parameters you
+                        want as kwargs.  (default: None) 
+    :param num:         Which number catalog are we reading.  e.g. for NG correlations the catalog
+                        for the N has num=0, the one for G has num=1. (default: 0)
+    :param logger:      If desired, a logger object for logging. (default: None, in which case
+                        one will be built according to the config dict's verbose level.)
+    :param is_rand:     If this is a random file, then setting is_rand to True will let them
+                        skip k_col, g1_col, and g2_col if they were set for the main catalog.
+                        (default: False)
+    :param x:           The x column (default: None)
+    :param y:           The y column (default: None)
+    :param ra:          The ra column (default: None)
+    :param dec:         The dec column (default: None)
+    :param r:           The r column (default: None)
+    :param w:           The w column (default: None)
+    :param flag:        The flag column (default: None)
+    :param g1:          The g1 column (default: None)
+    :param g2:          The g2 column (default: None)
+    :param k:           The k column (default: None)
     """
     def __init__(self, file_name=None, config=None, num=0, logger=None, is_rand=False,
                  x=None, y=None, ra=None, dec=None, r=None, w=None, flag=None,
@@ -155,16 +172,16 @@ class Catalog(object):
                 if ra is None or dec is None:
                     raise AttributeError("ra and dec must both be provided")
             self.name = ''
-            if x is not None: self.x = numpy.array(x,dtype=float)
-            if y is not None: self.y = numpy.array(y,dtype=float)
-            if ra is not None: self.ra = numpy.array(ra,dtype=float)
-            if dec is not None: self.dec = numpy.array(dec,dtype=float)
-            if r is not None: self.r = numpy.array(r,dtype=float)
-            if w is not None: self.w = numpy.array(w,dtype=float)
-            if flag is not None: self.flag = numpy.array(flag,dtype=int)
-            if g1 is not None: self.g1 = numpy.array(g1,dtype=float)
-            if g2 is not None: self.g2 = numpy.array(g2,dtype=float)
-            if k is not None: self.k = numpy.array(k,dtype=float)
+            self.x = self.makeArray(x,'x')
+            self.y = self.makeArray(y,'y')
+            self.ra = self.makeArray(ra,'ra')
+            self.dec = self.makeArray(dec,'dec')
+            self.r = self.makeArray(r,'r')
+            self.w = self.makeArray(w,'w')
+            self.flag = self.makeArray(flag,'flag',int)
+            self.g1 = self.makeArray(g1,'g1')
+            self.g2 = self.makeArray(g2,'g2')
+            self.k = self.makeArray(k,'k')
 
 
         # Apply units to x,y,ra,dec
@@ -190,8 +207,12 @@ class Catalog(object):
         # Apply flips if requested
         flip_g1 = treecorr.config.get_from_list(self.config,'flip_g1',num,bool,False)
         flip_g2 = treecorr.config.get_from_list(self.config,'flip_g2',num,bool,False)
-        if flip_g1: self.g1 = -self.g1
-        if flip_g2: self.g2 = -self.g2
+        if flip_g1: 
+            self.logger.info("   Flipping sign of g1.")
+            self.g1 = -self.g1
+        if flip_g2:
+            self.logger.info("   Flipping sign of g2.")
+            self.g2 = -self.g2
 
         # Convert the flag to a weight
         if self.flag is not None:
@@ -231,9 +252,9 @@ class Catalog(object):
         if self.dec is not None: self.dec = self.dec[start:end]
         if self.r is not None: self.r = self.r[start:end]
         if self.w is not None: self.w = self.w[start:end]
-        if self.k is not None: self.k = self.k[start:end]
         if self.g1 is not None: self.g1 = self.g1[start:end]
         if self.g2 is not None: self.g2 = self.g2[start:end]
+        if self.k is not None: self.k = self.k[start:end]
 
         # Check that all columns have the same length:
         if self.x is not None: 
@@ -301,7 +322,32 @@ class Catalog(object):
         self.logger.info("   nobj = %d",nobj)
 
 
+    def makeArray(self, col, col_str, dtype=float):
+        """Turn the input column into a numpy array if it wasn't already.
+        Also make sure the input in 1-d.
+
+        :param col:     The input column to be converted into a numpy array.
+        :param col_str: The name of the column.  Used only as information in logging output.
+        :param dtype:   The dtype for the returned array.  (default: float)
+
+        :returns:       The column converted to a 1-d numpy array.
+        """
+        if col is not None:
+            col = numpy.array(col,dtype=dtype)
+            if len(col.shape) != 1:
+                s = col.shape
+                col = col.reshape(-1)
+                self.logger.warn("Warning: Input %s column was not 1-d.",col_str)
+                self.logger.warn("         Reshaping from %s to %s",s,col.shape)
+        return col
+
+
     def checkForNaN(self, col, col_str):
+        """Check if the column has any NaNs.  If so, set those rows to have w[k]=0.
+
+        :param col:     The input column to check.
+        :param col_str: The name of the column.  Used only as information in logging output.
+        """
         if col is not None and any(numpy.isnan(col)):
             index = numpy.where(numpy.isnan(col))[0]
             self.logger.warn("Warning: NaNs found in %s column.  Skipping rows %s.",
@@ -313,6 +359,10 @@ class Catalog(object):
 
     def read_ascii(self, file_name, num=0, is_rand=False):
         """Read the catalog from an ASCII file
+
+        :param file_name:   The name of the file to read in.
+        :param num:         Which number catalog are we reading. (default: 0)
+        :param is_rand:     Is this a random catalog? (default: False)
         """
         import numpy
         comment_marker = self.config.get('comment_marker','#')
@@ -445,6 +495,10 @@ class Catalog(object):
 
     def read_fits(self, file_name, num=0, is_rand=False):
         """Read the catalog from a FITS file
+
+        :param file_name:   The name of the file to read in.
+        :param num:         Which number catalog are we reading. (default: 0)
+        :param is_rand:     Is this a random catalog? (default: False)
         """
         # Get the column names
         x_col = treecorr.config.get_from_list(self.config,'x_col',num,str,'0')
@@ -503,6 +557,24 @@ class Catalog(object):
     def read_fitsio(self, file_name, num, is_rand,
                     x_col, y_col, ra_col, dec_col, r_col, w_col, flag_col,
                     g1_col, g2_col, k_col):
+        """Read the catalog from a FITS file using the fitsio package
+
+        This is normally not called directly.  Use :meth:`~treecorr.Catalog.read_fits` instead.
+
+        :param file_name:   The name of the file to read in.
+        :param num:         Which number catalog are we reading.
+        :param is_rand:     Is this a random catalog?
+        :param x_col:       The name for x_col
+        :param y_col:       The name for y_col
+        :param ra_col:      The name for ra_col
+        :param dec_col:     The name for dec_col
+        :param r_col:       The name for r_col
+        :param w_col:       The name for w_col
+        :param flag_col:    The name for flat_col
+        :param g1_col:      The name for g1_col
+        :param g2_col:      The name for g2_col
+        :param k_col:       The name for k_col
+        """
         import fitsio
 
         hdu = treecorr.config.get_from_list(self.config,'hdu',num,int,1)
@@ -559,7 +631,7 @@ class Catalog(object):
             if is_rand: return
 
             # Read g1,g2
-            if g1_col != '0' and g2_col != '0':
+            if g1_col != '0':
                 g1_hdu = treecorr.config.get_from_list(self.config,'g1_hdu',num,int,hdu)
                 g2_hdu = treecorr.config.get_from_list(self.config,'g2_hdu',num,int,hdu)
                 if (g1_col not in fits[g1_hdu].get_colnames() or
@@ -593,6 +665,24 @@ class Catalog(object):
     def read_pyfits(self, file_name, num, is_rand,
                     x_col, y_col, ra_col, dec_col, r_col, w_col, flag_col,
                     g1_col, g2_col, k_col):
+        """Read the catalog from a FITS file using the pyfits or astropy.io package
+
+        This is normally not called directly.  Use :meth:`~treecorr.Catalog.read_fits` instead.
+
+        :param file_name:   The name of the file to read in.
+        :param num:         Which number catalog are we reading.
+        :param is_rand:     Is this a random catalog?
+        :param x_col:       The name for x_col
+        :param y_col:       The name for y_col
+        :param ra_col:      The name for ra_col
+        :param dec_col:     The name for dec_col
+        :param r_col:       The name for r_col
+        :param w_col:       The name for w_col
+        :param flag_col:    The name for flat_col
+        :param g1_col:      The name for g1_col
+        :param g2_col:      The name for g2_col
+        :param k_col:       The name for k_col
+        """
         try:
             import astropy.io.fits as pyfits
         except:
@@ -683,10 +773,20 @@ class Catalog(object):
                     self.logger.debug('read k = %s',str(self.k))
 
 
-    def getNField(self, min_sep, max_sep, b, logger=None, config=None):
+    def getNField(self, min_sep, max_sep, b, split_method='mean', logger=None):
         """Return an NField based on the positions in this catalog.
 
         The NField object is cached, so this is efficient to call multiple times.
+
+        :param min_sep:         The minimum separation between points that will be needed.
+        :param max_sep:         The maximum separation between points that will be needed.
+        :param b:               The b parameter that will be used for the correlation function.
+                                This should be bin_size * bin_slop.
+        :param split_method:    Which split method to use ('mean', 'median', or 'middle')
+                                (default: 'mean')
+        :param logger:          A logger file if desired (default: self.logger)
+
+        :returns:               A :class:`~treecorr.NField` object
         """
         if (not hasattr(self,'nfield') 
             or min_sep != self.nfield.min_sep
@@ -695,17 +795,25 @@ class Catalog(object):
 
             if logger is None:
                 logger = self.logger
-            if config is None:
-                config = self.config
-            self.nfield = treecorr.NField(self,min_sep,max_sep,b,logger,config)
+            self.nfield = treecorr.NField(self,min_sep,max_sep,b,logger)
 
         return self.nfield
 
 
-    def getKField(self, min_sep, max_sep, b, logger=None, config=None):
+    def getKField(self, min_sep, max_sep, b, split_method='mean', logger=None):
         """Return a KField based on the k values in this catalog.
 
         The KField object is cached, so this is efficient to call multiple times.
+
+        :param min_sep:         The minimum separation between points that will be needed.
+        :param max_sep:         The maximum separation between points that will be needed.
+        :param b:               The b parameter that will be used for the correlation function.
+                                This should be bin_size * bin_slop.
+        :param split_method:    Which split method to use ('mean', 'median', or 'middle')
+                                (default: 'mean')
+        :param logger:          A logger file if desired (default: self.logger)
+
+        :returns:               A :class:`~treecorr.KField` object
         """
         if (not hasattr(self,'kfield') 
             or min_sep != self.kfield.min_sep
@@ -716,17 +824,25 @@ class Catalog(object):
                 raise AttributeError("k are not defined.")
             if logger is None:
                 logger = self.logger
-            if config is None:
-                config = self.config
-            self.kfield = treecorr.KField(self,min_sep,max_sep,b,logger,config)
+            self.kfield = treecorr.KField(self,min_sep,max_sep,b,logger)
 
         return self.kfield
 
 
-    def getGField(self, min_sep, max_sep, b, logger=None, config=None):
+    def getGField(self, min_sep, max_sep, b, split_method='mean', logger=None):
         """Return a GField based on the g1,g2 values in this catalog.
 
         The GField object is cached, so this is efficient to call multiple times.
+
+        :param min_sep:         The minimum separation between points that will be needed.
+        :param max_sep:         The maximum separation between points that will be needed.
+        :param b:               The b parameter that will be used for the correlation function.
+                                This should be bin_size * bin_slop.
+        :param split_method:    Which split method to use ('mean', 'median', or 'middle')
+                                (default: 'mean')
+        :param logger:          A logger file if desired (default: self.logger)
+
+        :returns:               A :class:`~treecorr.GField` object
         """
         if (not hasattr(self,'gfield') 
             or min_sep != self.gfield.min_sep
@@ -737,58 +853,62 @@ class Catalog(object):
                 raise AttributeError("g1,g2 are not defined.")
             if logger is None:
                 logger = self.logger
-            if config is None:
-                config = self.config
-            self.gfield = treecorr.GField(self,min_sep,max_sep,b,logger,config)
+            self.gfield = treecorr.GField(self,min_sep,max_sep,b,logger)
 
         return self.gfield
 
 
-    def getNSimpleField(self, logger=None, config=None):
+    def getNSimpleField(self, logger=None):
         """Return an NSimpleField based on the positions in this catalog.
 
         The NSimpleField object is cached, so this is efficient to call multiple times.
+
+        :param logger:          A logger file if desired (default: self.logger)
+
+        :returns:               A :class:`~treecorr.NSimpleField` object
         """
         if not hasattr(self,'nsimplefield'):
             if logger is None:
                 logger = self.logger
-            if config is None:
-                config = self.config
-            self.nsimplefield = treecorr.NSimpleField(self,logger,config)
+            self.nsimplefield = treecorr.NSimpleField(self,logger)
 
         return self.nsimplefield
 
 
-    def getKSimpleField(self, logger=None, config=None):
+    def getKSimpleField(self, logger=None):
         """Return a KSimpleField based on the k values in this catalog.
 
         The KSimpleField object is cached, so this is efficient to call multiple times.
+
+        :param logger:          A logger file if desired (default: self.logger)
+
+        :returns:               A :class:`~treecorr.KSimpleField` object
         """
         if not hasattr(self,'ksimplefield'):
             if self.k is None:
                 raise AttributeError("k are not defined.")
             if logger is None:
                 logger = self.logger
-            if config is None:
-                config = self.config
-            self.ksimplefield = treecorr.KSimpleField(self,logger,config)
+            self.ksimplefield = treecorr.KSimpleField(self,logger)
 
         return self.ksimplefield
 
 
-    def getGSimpleField(self, logger=None, config=None):
+    def getGSimpleField(self, logger=None):
         """Return a GSimpleField based on the g1,g2 values in this catalog.
 
         The GSimpleField object is cached, so this is efficient to call multiple times.
+
+        :param logger:          A logger file if desired (default: self.logger)
+
+        :returns:               A :class:`~treecorr.GSimpleField` object
         """
         if not hasattr(self,'gsimplefield'):
             if self.g1 is None or self.g2 is None:
                 raise AttributeError("g1,g2 are not defined.")
             if logger is None:
                 logger = self.logger
-            if config is None:
-                config = self.config
-            self.gsimplefield = treecorr.GSimpleField(self,logger,config)
+            self.gsimplefield = treecorr.GSimpleField(self,logger)
 
         return self.gsimplefield
 
@@ -803,6 +923,8 @@ class Catalog(object):
                                        ra_units='hours', dec_units='degrees')
             >>> cat.ra_units = treecorr.degrees
             >>> cat.write('new_cat.dat')
+
+        :param file_name:   The name of the file to write to.
         """
         import numpy
 
@@ -869,7 +991,25 @@ def read_catalogs(config, key=None, list_key=None, num=0, logger=None, is_rand=N
 
     num indicates which key to use if any of the fields like x_col, flip_g1, etc. are lists.
     The default is 0, which means to use the first item in the list if they are lists.
+
+    :param config:      The configuration dict to use for the appropriate parameters
+    :param key:         Which key name to use for the file names. e.g. 'file_name' (default: None)
+    :param list_key:    Which key name to use for the name of a list file. e.g. 'file_list'.
+                        Either key or list_key is required.  (default: None)
+    :param num:         Which number catalog does this correspond to. e.g. file_name should use
+                        num=0, file_name2 should use num=1.  (default: 0)
+    :param logger:      If desired, a logger object for logging. (default: None, in which case
+                        one will be built according to the config dict's verbose level.)
+    :param is_rand:     If this is a random file, then setting is_rand to True will let them
+                        skip k_col, g1_col, and g2_col if they were set for the main catalog.
+                        (default: False)
+
+    :returns:           A list of Catalogs
     """
+    if logger is None:
+        logger = treecorr.config.setup_logger(
+                treecorr.config.get(config,'verbose',int,0), config.get('log_file',None))
+
     if key is None and list_key is None:
         raise AttributeError("Must provide either %s or %s."%(key,list_key))
     if key is not None and key in config:
@@ -880,6 +1020,10 @@ def read_catalogs(config, key=None, list_key=None, num=0, logger=None, is_rand=N
         list_file = config[list_key]
         with open(list_file,'r') as fin:
             file_names = [ f.strip() for f in fin ]
+        if len(file_names) == 0:
+            logger.warn('Warning: %s provided, but no names were read from the file %s',
+                        list_key, list_file)
+            return []
     else:
         # If this key was required (i.e. file_name) then let the caller check this.
         return []
@@ -888,7 +1032,11 @@ def read_catalogs(config, key=None, list_key=None, num=0, logger=None, is_rand=N
             is_rand = 'rand' in key
         else:
             is_rand = 'rand' in list_key
-    if not isinstance(file_names,list): file_names = [ file_names ]
+    if not isinstance(file_names,list): 
+        file_names = file_names.split()
+        if len(file_names) == 0:
+            logger.warn('Warning: %s provided, but it seems to be an empty string',key)
+            return []
     return [ Catalog(file_name, config, num, logger, is_rand) for file_name in file_names ]
 
 
@@ -896,7 +1044,11 @@ def calculateVarG(cat_list):
     """Calculate the overall shear variance from a list of catalogs.
         
     The catalogs are assumed to be equivalent, so this is just the average shear
-    variance weighted by the number of objects in each catalog.
+    variance (per component) weighted by the number of objects in each catalog.
+
+    :param cat_list:    A Catalog or a list of Catalogs for which to calculate the shear variance.
+
+    :returns:           The shear variance per component, aka shape noise.
     """
     if len(cat_list) == 1:
         return cat_list[0].varg
@@ -913,6 +1065,10 @@ def calculateVarK(cat_list):
         
     The catalogs are assumed to be equivalent, so this is just the average kappa
     variance weighted by the number of objects in each catalog.
+
+    :param cat_list:    A Catalog or a list of Catalogs for which to calculate the kappa variance.
+
+    :returns:           The kappa variance
     """
     if len(cat_list) == 1:
         return cat_list[0].vark
@@ -925,3 +1081,52 @@ def calculateVarK(cat_list):
         return vark / ntot
 
 
+def isGColRequired(config, num):
+    """A quick helper function that checks whether we need to bother reading the g1,g2 columns.
+
+    It checks the config dict for the output file names gg_file_name, ng_file_name (only if
+    num == 1), etc.  If the output files indicate that we don't need the g1/g2 columns, then
+    we don't need to raise an error if the g1_col or g2_col is invalid.
+    
+    This makes it easier to specify columns. e.g. for an NG correlation function, the 
+    first catalog does not need to have the gamma columns, and typically wouldn't.  So
+    if you specify g1_col=5, g2_col=6, say, and the first catalog does not have these columns,
+    you would normally get an error. 
+    
+    But instead, we check that the calculation is going to be NG from the presence of an
+    ng_file_name parameter, and we let the would-be error pass.
+
+    :param config:  The configuration file to check.
+    :param num:     Which number catalog are we working on.
+
+    :returns:       True if some output file requires this catalog to have valid g1/g2 columns,
+                    False if not.
+
+    """
+    return ( 'gg_file_name' in config
+             or 'm2_file_name' in config
+             or 'norm_file_name' in config
+             or (num==1 and 'ng_file_name' in config)
+             or (num==1 and 'nm_file_name' in config)
+             or (num==1 and 'kg_file_name' in config) )
+
+
+
+def isKColRequired(config, num):
+    """A quick helper function that checks whether we need to bother reading the k column.
+
+    The logic here is the same as for :func:`~treecorr.catalog.isGColRequired`, but we check
+    for output files that require the kappa column rather than gamma.
+
+    :param config:  The configuration file to check.
+    :param num:     Which number catalog are we working on.
+
+    :returns:       True if some output file requires this catalog to have valid g1/g2 columns,
+                    False if not.
+
+    """
+    return ( 'kk_file_name' in config
+             or (num==0 and 'kg_file_name' in config)
+             or (num==1 and 'nk_file_name' in config) )
+
+
