@@ -10,16 +10,12 @@
 # 2. Redistributions in binary form must reproduce the above copyright notice,
 #    this list of conditions, and the disclaimer given in the documentation
 #    and/or other materials provided with the distribution.
-"""@file celestial.py
-The CelestialCoord class describing coordinates on the celestial sphere.
-"""
 
 # Note: This file was original written for GalSim.  But since I was the author
 # of it there, I can republish it here under the TreeCorr license too.  I've
 # made a few (slight) modifications from the GalSim version.
 
 
-# The value of various angle units in radians for easy conversion.
 angle_units = {
     'arcsec' : 4.84813681109537e-6,
     'arcmin' : 2.90888208665722e-4,
@@ -27,53 +23,54 @@ angle_units = {
     'hour' : 2.61799387799149e-1,
     'rad' : 1.,
 }
+"""The value of various angle units in radians for easy conversion.
 
-# Convenient shorthand:
-arcsec = angle_units['arcsec']
-arcmin = angle_units['arcmin']
-degrees = angle_units['deg']
-hours = angle_units['hour']
-radians = angle_units['rad']
+Note that there are also shorthand equivalents for these.  e.g. Either::
+
+    4. * treecorr.angle_units['arcsec']
+    4. * treecorr.arcsec
+
+would represent 4 arcsec in radians.
+"""
+
+arcsec = angle_units['arcsec']  #: 1 arcsec in radians
+arcmin = angle_units['arcmin']  #: 1 arcmin in radians
+degrees = angle_units['deg']    #: 1 degree in radians
+hours = angle_units['hour']     #: 1 hour of angle in radians
+radians = angle_units['rad']    #: 1 radian in radians
 
 class CelestialCoord(object):
     """This class defines a position on the celestial sphere, normally given by
     two angles, `ra` and `dec`.
 
-    Mostly this class exists to enforce the units when a position is really a location on
-    the celestial sphere rather than using PositionD as we normally do for positions.
-    In that role, it can be considered a lightweight wrapper around two angles, `ra` and `dec`.
-    They are accessible as `coord.ra` and `coord.dec`.
+    This class is used to perform various calculations in spherical coordinates, such
+    as the angular distance between two points in the sky, the angles in spherical triangles,
+    projecting from sky coordinates onto a Euclidean tangent plane, etc.
 
-    However, there are a few useful functions that we provide.
-
-    The distance between two coordinate positions can be calculated with
-
-        >>> d = coord.distanceTo(other_coord)
-
-    There are several tangent plane projections you can use:
-        - a Lambert projection, which preserves area
-        - a stereographic projection, which preserves angles
-        - a gnomonic projection, which makes all great circles straight lines
-        - a Postel projection, which preserves distances from the tangent point
-    See the project() and deproject() functions for details.
-
-    You can also precess a coordinate from one epoch to another and get galactic coordinates
-    with, e.g.
-
-        >>> coord1950 = coord2000.precess(2000, 1950)
-        >>> el, b = coord.galactic()
-
-    We don't use either of these for anything within TreeCorr, but I had the code to do it
-    lying around, so I included it here in case someone might find it useful.
-
-    Initialization
-    --------------
-    A CelestialCoord object is initialized with the following command:
+    A `CelestialCoord` object is constructed from the right ascension and declination:
 
         >>> coord = treecorr.CelestialCoord(ra, dec)
 
-    @param ra       The right ascension in radians.
-    @param dec      The declination in radian.
+    The input angles are assumed to be in radians, but we have some helper variables to 
+    convert from other units:
+
+    - :const:`treecorr.arcsec`    The value of 1 arcsec in radians = pi/(180*3600)
+    - :const:`treecorr.arcmin`    The value of 1 arcmin in radians = pi/(180*60)
+    - :const:`treecorr.degrees`   The value of 1 degree in radians = pi/180
+    - :const:`treecorr.hours`     The value of 1 hour in radians   = pi/12
+    - :const:`treecorr.radians`   The value of 1 radian in radians = 1
+
+    So if you have ra in hours, and dec in degrees, you can write:
+
+        >>> coord = treecorr.CelestialCoord(ra * treecorr.hours, dec * treecorr.degrees)
+
+    After construction, you can access the ra and dec values as read-only attributes.
+
+        >>> ra = coord.ra
+        >>> dec = coord.dec
+
+    :param ra:       The right ascension in radians.
+    :param dec:      The declination in radian.
     """
     def __init__(self, ra, dec):
         self._ra = ra
@@ -82,6 +79,7 @@ class CelestialCoord(object):
 
     @property
     def ra(self): return self._ra
+
     @property
     def dec(self): return self._dec
 
@@ -101,6 +99,9 @@ class CelestialCoord(object):
     def distanceTo(self, other):
         """Returns the great circle distance between this coord and another one.
         The return value is in radians.
+
+        :param other:   Another `CelestialCoord` object.
+        :returns:       The great circle distance in radians between this coord and `other`.
         """
         # The easiest way to do this in a way that is stable for small separations
         # is to calculate the (x,y,z) position on the unit sphere corresponding to each
@@ -129,7 +130,12 @@ class CelestialCoord(object):
 
 
     def angleBetween(self, coord1, coord2):
-        """Find the open angle at the location of the current coord between `coord1` and `coord2`.
+        """Find the open angle at the location of the current coord between `coord1` and
+        `coord2`.
+
+        :param coord1:  Another `CelestialCoord` object.
+        :param coord2:  A third `CelestialCoord` object.
+        :returns:       The angle in radians between the great circles to the two other coords.
         """
         # Call A = coord1, B = coord2, C = self
         # Then we are looking for the angle ACB.
@@ -161,8 +167,13 @@ class CelestialCoord(object):
 
 
     def area(self, coord1, coord2):
-        """Find the area of the spherical triangle defined by the current coord, `coord1`,
+        """Find the area of the spherical triangle defined by the current coordinate, `coord1`,
         and `coord2`, returning the area in steradians.
+
+        :param coord1:  Another `CelestialCoord` object.
+        :param coord2:  A third `CelestialCoord` object.
+        :returns:       The area in steradians of the spherical triangle defined by the three
+                        coords.
         """
         # The area of a spherical triangle is defined by the "spherical excess", E.
         # There are several formulae for E:
@@ -220,26 +231,27 @@ class CelestialCoord(object):
         a tangent plane projection around the current coordinate, with +v pointing north and
         +u pointing west.
 
-        There are currently four options for the projection, which you can specify with the
-        optional `projection` keyword argument:
+        There are currently four options for the projection, which you can specify as a string
+        value for the `projection` keyword argument:
 
-            'lambert' [default] uses a Lambert azimuthal projection, which preserves
-                    area, but not angles.  For more information, see
-                    http://mathworld.wolfram.com/LambertAzimuthalEqual-AreaProjection.html
-            'stereographic' uses a stereographic proejection, which preserves angles, but
-                    not area.  For more information, see
-                    http://mathworld.wolfram.com/StereographicProjection.html
-            'gnomonic' uses a gnomonic projection (i.e. a projection from the center of the
-                    sphere), which has the property that all great circles become straight 
-                    lines.  For more information, see
-                    http://mathworld.wolfram.com/GnomonicProjection.html
-            'postel' uses a Postel equidistant proejection, which preserves distances from
-                    the projection point, but not area or angles.  For more information, see
-                    http://mathworld.wolfram.com/AzimuthalEquidistantProjection.html
+        - 'lambert' Uses a Lambert azimuthal projection, which preserves the area of small
+          patches, but not the angles between points in these patches.  For more information, see
+          http://mathworld.wolfram.com/LambertAzimuthalEqual-AreaProjection.html
+        - 'stereographic' Uses a stereographic proejection, which preserves angles between points
+          in small patches, but not area.  For more information, see 
+          http://mathworld.wolfram.com/StereographicProjection.html
+        - 'gnomonic' Uses a gnomonic projection (i.e. a projection from the center of the sphere),
+          which has the property that all great circles become straight lines.  For more 
+          information, see http://mathworld.wolfram.com/GnomonicProjection.html
+        - 'postel' Uses a Postel equidistant proejection, which preserves distances from the
+          projection point, but not area or angles.  For more information, see
+          http://mathworld.wolfram.com/AzimuthalEquidistantProjection.html
 
         The distance or angle errors increase with distance from the projection point of course.
 
-        @returns (u,v) in radians as a tuple.
+        :param other:       The coordinate to be projected relative to the current coord.
+        :param projection:  Which kind of projection to use. (default: 'lambert')
+        :returns:           The projected position (u,v) in radians as a tuple.
         """
         if projection not in [ 'lambert', 'stereographic', 'gnomonic', 'postel' ]:
             raise ValueError('Unknown projection ' + projection)
@@ -300,13 +312,20 @@ class CelestialCoord(object):
 
 
     def project_rad(self, ra, dec, projection):
-        """This is basically identical to the project() function except that the input `ra`, `dec`
-        are given in radians rather than packaged as a CelestialCoord object.
+        """This is basically identical to the :meth:`~treecorr.CelestialCoord.project` method 
+        except that the input `ra`, `dec` are given in radians rather than packaged as a 
+        `CelestialCoord` object.
 
-        Also, the output is returned as a tuple (x,y), rather than packaged as a PositionD object.
+        The main advantage to this is that it will work if `ra` and `dec` are NumPy arrays,
+        in which case the output `x`, `y` will also be NumPy arrays.
 
-        The main advantage to this is that it will work if `ra` and `dec` are NumPy arrays, in which
-        case the output `x`, `y` will also be NumPy arrays.
+        See the doc for :meth:`~treecorr.CelestialCoord.project` for more information about the 
+        kinds of projection.
+
+        :param ra:          The RA of the coordinate to be projected relative to the current coord.
+        :param dec:         The Dec of the coordinate to be projected relative to the current coord.
+        :param projection:  Which kind of projection to use. (default: 'lambert')
+        :returns:           The projected position (u,v) in radians as a tuple.
         """
         if projection not in [ 'lambert', 'stereographic', 'gnomonic', 'postel' ]:
             raise ValueError('Unknown projection ' + projection)
@@ -328,6 +347,14 @@ class CelestialCoord(object):
         i.e. This takes in a position (u,v) as a tuple and returns the corresponding celestial
         coordinate, using the current coordinate as the center point of the tangent plane
         projection.
+
+        See the doc for :meth:`~treecorr.CelestialCoord.project` for more information about the 
+        kinds of projection.
+
+        :param u:           The projected u value to be deprojected.
+        :param v:           The projected v value to be deprojected.
+        :param projection:  Which kind of projection to use. (default: 'lambert')
+        :returns:           The `CelestialCoord` corresponding to the given projected position.
         """
         if projection not in [ 'lambert', 'stereographic', 'gnomonic', 'postel' ]:
             raise ValueError('Unknown projection ' + projection)
@@ -401,11 +428,19 @@ class CelestialCoord(object):
 
     def deproject_rad(self, u, v, projection='lambert'):
         """This is basically identical to the deproject() function except that the output `ra`,
-        `dec` are returned as a tuple (ra, dec) in radians rather than packaged as a CelestialCoord
-        object.
+        `dec` are returned as a tuple (ra, dec) in radians rather than packaged as a 
+        `CelestialCoord` object.
 
-        The main advantage to this is that it will work if `u` and `v` are NumPy arrays, in which 
-        case the output `ra`, `dec` will also be NumPy arrays.
+        The main advantage to this is that it will work if `u` and `v` are NumPy arrays,
+        in which case the output `ra`, `dec` will also be NumPy arrays.
+
+        See the doc for :meth:`~treecorr.CelestialCoord.project` for more information about the 
+        kinds of projection.
+
+        :param u:           The projected u value to be deprojected.
+        :param v:           The projected v value to be deprojected.
+        :param projection:  Which kind of projection to use. (default: 'lambert')
+        :returns:           A tuple (ra, dec) of the deprojected coordinates.
         """
         if projection not in [ 'lambert', 'stereographic', 'gnomonic', 'postel' ]:
             raise ValueError('Unknown projection ' + projection)
@@ -421,7 +456,13 @@ class CelestialCoord(object):
         J = ( dra/du cos(dec)  dra/dv cos(dec) )
             (    ddec/du          ddec/dv      )
 
-        @returns the matrix as a tuple (J00, J01, J10, J11)
+        See the doc for :meth:`~treecorr.CelestialCoord.project` for more information about the 
+        kinds of projection.
+
+        :param u:           The projected u value to be deprojected.
+        :param v:           The projected v value to be deprojected.
+        :param projection:  Which kind of projection to use. (default: 'lambert')
+        :returns:           The matrix as a tuple (J00, J01, J10, J11)
         """
         if projection not in [ 'lambert', 'stereographic', 'gnomonic', 'postel' ]:
             raise ValueError('Unknown projection ' + projection)
@@ -496,9 +537,14 @@ class CelestialCoord(object):
 
     def precess(self, from_epoch, to_epoch):
         """This function precesses equatorial ra and dec from one epoch to another.
-           It is adapted from a set of fortran subroutines based on (a) pages 30-34 of
-           the Explanatory Supplement to the AE, (b) Lieske, et al. (1977) A&A 58, 1-16,
-           and (c) Lieske (1979) A&A 73, 282-284.
+
+        It is adapted from a set of fortran subroutines based on (a) pages 30-34 of
+        the Explanatory Supplement to the AE, (b) Lieske, et al. (1977) A&A 58, 1-16,
+        and (c) Lieske (1979) A&A 73, 282-284.
+
+        :param from_epoch:  The epoch to use for the current coord.
+        :param to_epoch:    The new epoch to precess to.
+        :returns:           A new `CelestialCoord` of the coordinates in the new epoch.
         """
         if from_epoch == to_epoch: return self
 
@@ -556,7 +602,8 @@ class CelestialCoord(object):
         precess from the current epoch to 1950.  The current epoch is assumed to be 2000
         by default, but you may also specify a different value with the epoch parameter.
 
-        @returns the longitude and latitude as a tuple (el, b) in radians.
+        :param epoch:   The epoch to assume for the current coordinates (default: 2000)
+        :returns:       The longitude and latitude as a tuple (el, b) in radians.
         """
         # cf. Lang, Astrophysical Formulae, page 13
         # cos(b) cos(el-33) = cos(dec) cos(ra-282.25)
